==> pegasus-support-1.6.30-sources.jar: com/thebeastshop/support/vo/exchange/ExchangeSimpleProductGoods.java <==
package com.thebeastshop.support.vo.exchange;

import com.thebeastshop.support.vo.product.SpvVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * @author feilong.gao
 * @Date 2018/5/23 17:06.
 * @Description
 */
public class ExchangeSimpleProductGoods extends ExchangeGoods {

    private String productCode;
    private String featureImage;
    private List<String> images = new ArrayList<String>();
    private SpvVO.BrandVO brand;
    private String name;
    private String summary;
    private BigDecimal price;

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getFeatureImage() {
        return featureImage;
    }

    public void setFeatureImage(String featureImage) {
        this.featureImage = featureImage;
    }

    public List<String> getImages() {
        return images;
    }

    public void setImages(List<String> images) {
        this.images = images;
    }

    public SpvVO.BrandVO getBrand() {
        return brand;
    }

    public void setBrand(SpvVO.BrandVO brand) {
        this.brand = brand;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("ExchangeSimpleProductGoods{");
        sb.append("productCode='").append(productCode).append('\'');
        sb.append(", featureImage='").append(featureImage).append('\'');
        sb.append(", images=").append(images);
        sb.append(", brand=").append(brand);
        sb.append(", name='").append(name).append('\'');
        sb.append(", summary='").append(summary).append('\'');
        sb.append(", price=").append(price);
        sb.append('}');
        return sb.toString();
    }
}

==> pegasus-support-2.2.9-sources.jar: com/thebeastshop/support/vo/exchange/ExchangeSimpleProductGoods.java <==
package com.thebeastshop.support.vo.exchange;

import com.thebeastshop.support.enums.exchange.ExchangeGoodsClassify;
import com.thebeastshop.support.vo.product.SpvVO;
import org.apache.commons.lang3.builder.ToStringBuilder;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author feilong.gao
 * @Date 2018/5/23 17:06.
 * @Description
 */
public class ExchangeSimpleProductGoods extends ExchangeGoods {

    private String productCode;
    private String featureImage;
    private List<String> images = new ArrayList<String>();
    private SpvVO.BrandVO brand;
    private String name;
    private String summary;
    private BigDecimal price;
    private Date startTime;            // 开始时间

    public ExchangeSimpleProductGoods() {
        classify = ExchangeGoodsClassify.PRODUCT;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getFeatureImage() {
        return featureImage;
    }

    public void setFeatureImage(String featureImage) {
        this.featureImage = featureImage;
    }

    public List<String> getImages() {
        return images;
    }

    public void setImages(List<String> images) {
        this.images = images;
    }

    public SpvVO.BrandVO getBrand() {
        return brand;
    }

    public void setBrand(SpvVO.BrandVO brand) {
        this.brand = brand;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("productCode", productCode)
                .append("featureImage", featureImage)
                .append("images", images)
                .append("brand", brand)
                .append("name", name)
                .append("classify", classify)
                .append("summary", summary)
                .append("price", price)
                .append("startTime", startTime)
                .toString();
    }
}
